@@ -36,7 +36,7 @@ build_time_vars = {'ABIFLAGS': 'd',
            '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
            '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
            '-mbranch-protection=standard -fasynchronous-unwind-tables '
-           '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv  -Og',
+           '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv  -O0 -Wno-cpp',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
@@ -100,12 +100,12 @@ build_time_vars = {'ABIFLAGS': 'd',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.9d',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.9.0/build/debug/coverage.info',
- 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.9.0/build/debug/lcov-report',
+ 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.9.2/build/debug/coverage.info',
+ 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.9.2/build/debug/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-             '-I/builddir/build/BUILD/Python-3.9.0/Include',
+             '-I/builddir/build/BUILD/Python-3.9.2/Include',
  'CXX': 'g++ -pthread',
  'DESTDIRS': '/usr /usr/lib64 /usr/lib64/python3.9 '
              '/usr/lib64/python3.9/lib-dynload',
@@ -218,6 +218,7 @@ build_time_vars = {'ABIFLAGS': 'd',
  'HAVE_DLOPEN': 1,
  'HAVE_DUP2': 1,
  'HAVE_DUP3': 1,
+ 'HAVE_DYLD_SHARED_CACHE_CONTAINS_PATH': 0,
  'HAVE_DYNAMIC_LOADING': 1,
  'HAVE_ENDIAN_H': 1,
  'HAVE_EPOLL': 1,
@@ -618,7 +619,7 @@ build_time_vars = {'ABIFLAGS': 'd',
  'MAINCC': 'gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
- 'MAKESETUP': '/builddir/build/BUILD/Python-3.9.0/Modules/makesetup',
+ 'MAKESETUP': '/builddir/build/BUILD/Python-3.9.2/Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
@@ -712,10 +713,10 @@ build_time_vars = {'ABIFLAGS': 'd',
                              '-mbranch-protection=standard '
                              '-fasynchronous-unwind-tables '
                              '-fstack-clash-protection -D_GNU_SOURCE -fPIC '
-                             '-fwrapv  -Og -O2 -flto=auto -ffat-lto-objects '
-                             '-fexceptions -g -grecord-gcc-switches -pipe '
-                             '-Wall -Werror=format-security '
-                             '-Wp,-D_FORTIFY_SOURCE=2 '
+                             '-fwrapv  -O0 -Wno-cpp -O2 -flto=auto '
+                             '-ffat-lto-objects -fexceptions -g '
+                             '-grecord-gcc-switches -pipe -Wall '
+                             '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wp,-D_GLIBCXX_ASSERTIONS '
                              '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                              '-fstack-protector-strong '
@@ -740,10 +741,10 @@ build_time_vars = {'ABIFLAGS': 'd',
                              '-mbranch-protection=standard '
                              '-fasynchronous-unwind-tables '
                              '-fstack-clash-protection -D_GNU_SOURCE -fPIC '
-                             '-fwrapv -fno-semantic-interposition -Og '
-                             '-I/builddir/build/BUILD/Python-3.9.0/Include/internal '
+                             '-fwrapv -fno-semantic-interposition -O0 -Wno-cpp '
+                             '-I/builddir/build/BUILD/Python-3.9.2/Include/internal '
                              '-IObjects -IInclude -IPython -I. '
-                             '-I/builddir/build/BUILD/Python-3.9.0/Include '
+                             '-I/builddir/build/BUILD/Python-3.9.2/Include '
                              '-fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare '
               '-DDYNAMIC_ANNOTATIONS_ENABLED=1  -O2  -fexceptions -g '
@@ -761,7 +762,7 @@ build_time_vars = {'ABIFLAGS': 'd',
               '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
               '-fstack-protector-strong   -mbranch-protection=standard '
               '-fasynchronous-unwind-tables -fstack-clash-protection '
-              '-D_GNU_SOURCE -fPIC -fwrapv  -Og',
+              '-D_GNU_SOURCE -fPIC -fwrapv  -O0 -Wno-cpp',
  'PY_CFLAGS_NODIST': '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
                      '-grecord-gcc-switches -pipe -Wall '
                      '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
@@ -787,8 +788,8 @@ build_time_vars = {'ABIFLAGS': 'd',
                      '-mbranch-protection=standard '
                      '-fasynchronous-unwind-tables -fstack-clash-protection '
                      '-D_GNU_SOURCE -fPIC -fwrapv -fno-semantic-interposition '
-                     '-Og '
-                     '-I/builddir/build/BUILD/Python-3.9.0/Include/internal',
+                     '-O0 -Wno-cpp '
+                     '-I/builddir/build/BUILD/Python-3.9.2/Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare '
                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1  -O2  -fexceptions -g '
@@ -806,7 +807,7 @@ build_time_vars = {'ABIFLAGS': 'd',
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
                    '-fstack-protector-strong   -mbranch-protection=standard '
                    '-fasynchronous-unwind-tables -fstack-clash-protection '
-                   '-D_GNU_SOURCE -fPIC -fwrapv  -Og -O2 -flto=auto '
+                   '-D_GNU_SOURCE -fPIC -fwrapv  -O0 -Wno-cpp -O2 -flto=auto '
                    '-ffat-lto-objects -fexceptions -g -grecord-gcc-switches '
                    '-pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS '
@@ -828,10 +829,10 @@ build_time_vars = {'ABIFLAGS': 'd',
                    '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
                    '-mbranch-protection=standard -fasynchronous-unwind-tables '
                    '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv '
-                   '-fno-semantic-interposition -Og '
-                   '-I/builddir/build/BUILD/Python-3.9.0/Include/internal '
+                   '-fno-semantic-interposition -O0 -Wno-cpp '
+                   '-I/builddir/build/BUILD/Python-3.9.2/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
-                   '-I/builddir/build/BUILD/Python-3.9.0/Include -fPIC '
+                   '-I/builddir/build/BUILD/Python-3.9.2/Include -fPIC '
                    '-DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now   -g  '
                     '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now   -g '
@@ -843,7 +844,7 @@ build_time_vars = {'ABIFLAGS': 'd',
                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld  '
                     '-fno-semantic-interposition -g',
  'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-                '-I/builddir/build/BUILD/Python-3.9.0/Include',
+                '-I/builddir/build/BUILD/Python-3.9.2/Include',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now   -g  -Wl,-z,relro '
                '-Wl,--as-needed  -Wl,-z,now   -g',
@@ -876,8 +877,8 @@ build_time_vars = {'ABIFLAGS': 'd',
                         '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
                         '-mbranch-protection=standard '
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
-                        '-D_GNU_SOURCE -fPIC -fwrapv  -Og -O2 -flto=auto '
-                        '-ffat-lto-objects -fexceptions -g '
+                        '-D_GNU_SOURCE -fPIC -fwrapv  -O0 -Wno-cpp -O2 '
+                        '-flto=auto -ffat-lto-objects -fexceptions -g '
                         '-grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -902,10 +903,10 @@ build_time_vars = {'ABIFLAGS': 'd',
                         '-mbranch-protection=standard '
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
                         '-D_GNU_SOURCE -fPIC -fwrapv '
-                        '-fno-semantic-interposition -Og '
-                        '-I/builddir/build/BUILD/Python-3.9.0/Include/internal '
+                        '-fno-semantic-interposition -O0 -Wno-cpp '
+                        '-I/builddir/build/BUILD/Python-3.9.2/Include/internal '
                         '-IObjects -IInclude -IPython -I. '
-                        '-I/builddir/build/BUILD/Python-3.9.0/Include -fPIC',
+                        '-I/builddir/build/BUILD/Python-3.9.2/Include -fPIC',
  'Py_DEBUG': 1,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -914,7 +915,7 @@ build_time_vars = {'ABIFLAGS': 'd',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.9.0/build/debug',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.9.2/build/debug',
  'SCRIPTDIR': '/usr/lib64',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '@SGI_ABI@',
@@ -944,7 +945,7 @@ build_time_vars = {'ABIFLAGS': 'd',
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-39d-aarch64-linux-gnu',
  'SRCDIRS': 'Parser Parser/pegen Objects Python Modules Modules/_io Programs',
- 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.9.0/Tools/gdb/libpython.py',
+ 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.9.2/Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -956,12 +957,12 @@ build_time_vars = {'ABIFLAGS': 'd',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.9.0/build/debug '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.9.2/build/debug '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.9.0/build/debug '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.9.2/build/debug '
                './python '
-               '/builddir/build/BUILD/Python-3.9.0/Tools/scripts/run_tests.py',
+               '/builddir/build/BUILD/Python-3.9.2/Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
@@ -970,10 +971,10 @@ build_time_vars = {'ABIFLAGS': 'd',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
  'UPDATE_FILE': 'python3.9 '
-                '/builddir/build/BUILD/Python-3.9.0/Tools/scripts/update_file.py',
+                '/builddir/build/BUILD/Python-3.9.2/Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
  'VERSION': '3.9',
- 'VPATH': '/builddir/build/BUILD/Python-3.9.0',
+ 'VPATH': '/builddir/build/BUILD/Python-3.9.2',
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
@@ -985,9 +986,9 @@ build_time_vars = {'ABIFLAGS': 'd',
  'WITH_VALGRIND': 1,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/builddir/build/BUILD/Python-3.9.0/build/debug',
- 'abs_srcdir': '/builddir/build/BUILD/Python-3.9.0',
+ 'abs_builddir': '/builddir/build/BUILD/Python-3.9.2/build/debug',
+ 'abs_srcdir': '/builddir/build/BUILD/Python-3.9.2',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
- 'srcdir': '/builddir/build/BUILD/Python-3.9.0'}
+ 'srcdir': '/builddir/build/BUILD/Python-3.9.2'}
